package io.renren.modules.admin.controller;

import java.io.File;
import java.util.Arrays;
import java.util.Map;

import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.beans.factory.annotation.Value;

import io.renren.modules.admin.entity.MeetingImagesEntity;
import io.renren.modules.admin.service.MeetingImagesService;
import io.renren.common.utils.PageUtils;
import io.renren.common.utils.R;



/**
 * 
 *
 * @author huwhois
 * @email huwhois@163.com
 * @date 2021-10-21 16:25:26
 */
@RestController
@RequestMapping("admin/meetingimages")
public class MeetingImagesController {
    @Value("${fyhs-meeting.file.datapath}")
    private String dataPath; // 读取配置文件中的指定目录
    @Autowired
    private MeetingImagesService meetingImagesService;

    /**
     * 列表
     */
    @RequestMapping("/list")
    @RequiresPermissions("admin:meetingimages:list")
    public R list(@RequestParam Map<String, Object> params){
        PageUtils page = meetingImagesService.queryPage(params);

        return R.ok().put("page", page);
    }

    /**
     * 信息
     */
    @RequestMapping("/info/{id}")
    @RequiresPermissions("admin:meetingimages:info")
    public R info(@PathVariable("id") Long id){
		MeetingImagesEntity meetingImages = meetingImagesService.getById(id);

        return R.ok().put("meetingImages", meetingImages);
    }

    /**
     * 保存
     */
    @RequestMapping("/save")
    @RequiresPermissions("admin:meetingimages:save")
    public R save(@RequestBody MeetingImagesEntity meetingImages){
		meetingImagesService.save(meetingImages);

        return R.ok();
    }

    /**
     * 修改
     */
    @RequestMapping("/update")
    @RequiresPermissions("admin:meetingimages:update")
    public R update(@RequestBody MeetingImagesEntity meetingImages){
		meetingImagesService.updateById(meetingImages);

        return R.ok();
    }

    /**
     * 删除
     */
    @RequestMapping("/delete/{id}")
    @RequiresPermissions("admin:meetingimages:delete")
    public R delete(@PathVariable("id") Long id){
        MeetingImagesEntity meetingImages = meetingImagesService.getById(id);

        String filePath = dataPath + meetingImages.getUrl();
        String thumbPath =  dataPath + meetingImages.getThumb();

        File file = new File(filePath);
        File thumb = new File(thumbPath);
        if (file.exists()) {
            file.delete();
            System.out.println(meetingImages.getTitle() + " ===========删除成功=================");
        } else {
            System.out.println(meetingImages.getTitle() + "===============删除失败==============");
        }
        if (thumb.exists()) {
            thumb.delete();
            System.out.println(meetingImages.getTitle() + " ===========删除成功=================");
        } else {
            System.out.println(meetingImages.getTitle() + "===============删除失败==============");
        }

		meetingImagesService.removeById(id);

        return R.ok();
    }

}
