package io.renren.modules.admin.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.Date;

import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import io.renren.modules.admin.entity.OrganizationEntity;
import io.renren.modules.admin.service.OrganizationService;
import io.renren.common.validator.ValidatorUtils;
import io.renren.common.validator.group.AddGroup;
import io.renren.common.validator.group.UpdateGroup;
import io.renren.common.utils.PageUtils;
import io.renren.common.utils.R;



/**
 * VIEW
 *
 * @author huwhois
 * @email huwhois@gmail.com
 * @date 2020-07-08 09:32:07
 */
@RestController
@RequestMapping("admin/organization")
public class OrganizationController {
    @Autowired
    private OrganizationService organizationService;

    /**
     * 列表
     */
    @GetMapping("/list")
    @RequiresPermissions("admin:organization:list")
    public R list(@RequestParam Map<String, Object> params){
        PageUtils page = organizationService.queryPage(params);

        return R.ok().put("page", page);
    }

    /**
     * 信息
     */
    @RequestMapping("/info/{id}")
    @RequiresPermissions("admin:organization:info")
    public R info(@PathVariable("id") Long id){
		OrganizationEntity organization = organizationService.getById(id);

        return R.ok().put("organization", organization);
    }

    /**
     * 保存
     */
    @RequestMapping("/save")
    @RequiresPermissions("admin:organization:save")
    public R save(@RequestBody OrganizationEntity organization){
        ValidatorUtils.validateEntity(organization, AddGroup.class);
        organization.setCreateTime(new Date());
		organizationService.save(organization);

        return R.ok();
    }

    /**
     * 修改
     */
    @RequestMapping("/update")
    @RequiresPermissions("admin:organization:update")
    public R update(@RequestBody OrganizationEntity organization){
        ValidatorUtils.validateEntity(organization, UpdateGroup.class);
		organizationService.updateById(organization);

        return R.ok();
    }

    /**
     * 删除
     */
    @RequestMapping("/delete")
    @RequiresPermissions("admin:organization:delete")
    public R delete(@RequestBody Long[] ids){
		organizationService.removeByIds(Arrays.asList(ids));

        return R.ok();
    }

    // /**
    //  * 单位历届参会统计
    //  */
    // @GetMapping("/prelist")
    // @RequiresPermissions("admin:organization:list")
    // public R previousList(@RequestParam Map<String, Object> params){
    //     if (!params.containsKey("organization")) {
    //         return R.error("单位名称不可为空");
    //     }

    //     String organization = (String) params.get("organization");

    //     List<OrganizationEntity>  list= organizationService.previousList(organization);

    //     return R.ok().put("list", list);
    // }

    // /**
    //  * 单位历届参会统计
    //  */
    // @GetMapping("/attendlist")
    // @RequiresPermissions("admin:organization:list")
    // public R attendlist(@RequestParam Map<String, Object> params){
    //     if (!params.containsKey("organization")) {
    //         return R.error("单位名称不可为空");
    //     }

    //     PageUtils page= organizationService.attendList(params);

    //     return R.ok().put("page", page);
    // }
}
